@@ -43,7 +43,7 @@ from __future__ import with_statement
 import base64, hashlib, os, re, string, tempfile, subprocess, types, functools, StringIO
 import fabric, fabric.api, fabric.operations, fabric.context_managers
 
-VERSION         = "0.5.3"
+VERSION         = "0.5.4"
 RE_SPACES       = re.compile("[\s\t]+")
 MAC_EOL         = "\n"
 UNIX_EOL        = "\n"
@@ -194,7 +194,7 @@ def sudo(*args, **kwargs):
 	with mode_sudo():
 		return run(*args, **kwargs)
 
-def connect( host ):
+def connect( host, user="root"):
 	"""Sets Fabric's current host to the given host. This is useful when
 	using Cuisine in standalone."""
 	# See http://docs.fabfile.org/en/1.3.2/usage/library.html
